
import { BrowserRouter, Routes, Route } from 'react-router-dom';
import { Toaster } from 'sonner';
import { TooltipProvider } from '@/components/ui/tooltip';
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { Suspense, lazy } from 'react';
import { ThemeProvider } from '@/components/theme-provider';
import { SupabaseAuthProvider } from '@/contexts/SupabaseAuthContext';
import MainLayout from '@/layouts/MainLayout';
import '@/App.css';

// Lazy load pages with preloading hints for better performance
const Index = lazy(() => import(/* webpackPreload: true */ '@/pages/Index'));
const PCBuilderPage = lazy(() => import(/* webpackPrefetch: true */ '@/pages/PCBuilder'));
const BuildLists = lazy(() => import(/* webpackPrefetch: true */ '@/pages/BuildLists'));
const Guides = lazy(() => import(/* webpackPrefetch: true */ '@/pages/Guides'));
const Purchase = lazy(() => import('@/pages/Purchase'));
const PaymentSuccess = lazy(() => import('@/pages/PaymentSuccess'));
const PaymentCanceled = lazy(() => import('@/pages/PaymentCanceled'));
const Account = lazy(() => import(/* webpackPrefetch: true */ '@/pages/Account'));
const Admin = lazy(() => import('@/pages/Admin'));
const StripeSync = lazy(() => import('@/pages/StripeSync'));
const OptimalBuildPage = lazy(() => import(/* webpackPrefetch: true */ '@/components/OptimalBuild/OptimalBuildPage'));
const AccessoriesPage = lazy(() => import('@/pages/AccessoriesPage'));
const GuideDetail = lazy(() => import('@/pages/GuideDetail'));

// Optimized query client with aggressive caching
const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      retry: 1,
      refetchOnWindowFocus: false,
      staleTime: 15 * 60 * 1000, // 15 minutes - increased from 10
      gcTime: 60 * 60 * 1000, // 1 hour - increased from 30 minutes
      refetchOnMount: false,
      refetchOnReconnect: false, // Prevent unnecessary refetches
    },
    mutations: {
      retry: 1,
    },
  },
});

// Enhanced loading component with modern design
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center bg-gradient-to-br from-background via-background to-muted/20">
    <div className="flex flex-col items-center gap-8 max-w-md w-full px-4">
      {/* Main loader with glowing effect */}
      <div className="relative">
        <div className="absolute inset-0 animate-ping rounded-full bg-primary/20 w-16 h-16"></div>
        <div className="relative animate-spin rounded-full h-16 w-16 border-4 border-muted border-t-primary shadow-lg"></div>
      </div>
      
      {/* Loading text with fade animation */}
      <div className="text-center space-y-3">
        <h2 className="text-2xl font-heading font-semibold text-foreground animate-pulse">
          PC4ME
        </h2>
        <p className="text-muted-foreground animate-fade-in">
          Loading your perfect PC building experience...
        </p>
      </div>
      
      {/* Skeleton content preview */}
      <div className="space-y-3 w-full max-w-sm animate-fade-in" style={{animationDelay: '0.3s'}}>
        <div className="h-3 bg-gradient-to-r from-muted via-muted/60 to-muted rounded-full animate-pulse"></div>
        <div className="h-3 bg-gradient-to-r from-muted via-muted/60 to-muted rounded-full animate-pulse w-4/5" style={{animationDelay: '0.1s'}}></div>
        <div className="h-3 bg-gradient-to-r from-muted via-muted/60 to-muted rounded-full animate-pulse w-3/5" style={{animationDelay: '0.2s'}}></div>
      </div>
      
      {/* Progress indicator */}
      <div className="w-full max-w-xs bg-muted rounded-full h-2 overflow-hidden">
        <div className="h-full bg-gradient-to-r from-primary to-accent rounded-full animate-pulse"></div>
      </div>
    </div>
  </div>
);

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <SupabaseAuthProvider>
        <ThemeProvider>
          <TooltipProvider delayDuration={100}>
            <BrowserRouter>
              <Suspense fallback={<PageLoader />}>
                <Routes>
                  <Route element={<MainLayout />}>
                    <Route path="/" element={<Index />} />
                    <Route path="/builder" element={<PCBuilderPage />} />
                    <Route path="/build-lists" element={<BuildLists />} />
                    <Route path="/guides" element={<Guides />} />
                    <Route path="/guide/:id" element={<GuideDetail />} />
                    <Route path="/accessories" element={<AccessoriesPage />} />
                    <Route path="/account" element={<Account />} />
                    <Route path="/optimal" element={<OptimalBuildPage />} />
                    <Route path="/payment-success" element={<PaymentSuccess />} />
                    <Route path="/payment-canceled" element={<PaymentCanceled />} />
                  </Route>
                  <Route path="/purchase" element={<Purchase />} />
                  <Route path="/admin" element={<Admin />} />
                  <Route path="/stripe-sync" element={<StripeSync />} />
                </Routes>
              </Suspense>
              <Toaster position="top-right" />
            </BrowserRouter>
          </TooltipProvider>
        </ThemeProvider>
      </SupabaseAuthProvider>
    </QueryClientProvider>
  );
}

export default App;
